@@ -20,11 +20,13 @@ import json
 import mercantile
 import shapely
 from geojson import Polygon
+from typing import Union
 
 # # Configs
 from mapillary.config.api.entities import Entities
 from mapillary.config.api.vector_tiles import VectorTiles
 from mapillary.models.api.entities import EntityAdapter
+from mapillary.models.api.general import GeneralAdapter
 
 # # Adapters
 from mapillary.models.api.vector_tiles import VectorTilesAdapter
@@ -36,7 +38,7 @@ from mapillary.models.client import Client
 from mapillary.models.exceptions import InvalidImageKeyError
 
 # # Class Representation
-from mapillary.models.geojson import GeoJSON
+from mapillary.models.geojson import GeoJSON, Coordinates
 
 # # Utilities
 from mapillary.utils.filter import pipeline
@@ -44,6 +46,7 @@ from mapillary.utils.format import (
     feature_to_geojson,
     merged_features_list_to_geojson,
     geojson_to_polygon,
+    coord_or_list_to_dict,
 )
 from mapillary.utils.verify import (
     image_check,
@@ -162,26 +165,15 @@ def get_image_close_to_controller(
 
 
 def get_image_looking_at_controller(
-    looker: dict,
-    at: dict,
+    at: Union[dict, Coordinates, list],
     filters: dict,
 ) -> GeoJSON:
     """
-    Extracting the GeoJSON for the image data from a 'looker' and 'at' coordinate view
+    Checks if the image with coordinates 'at' is looked with the given filters.
 
     :param filters: Filters to pass the data through
     :type filters: dict
 
-    :param looker: The dictionary of coordinates of the position of the looking from
-        coordinates. Format::
-
-            >>> {
-            >>>     'lng': 'longitude',
-            >>>     'lat': 'latitude'
-            >>> }
-
-    :type looker: dict
-
     :param at: The dict of coordinates of the position of the looking at
         coordinates. Format::
 
@@ -192,6 +184,9 @@ def get_image_looking_at_controller(
 
     :type at: dict
 
+    :param filters.zoom: The zoom level of the tiles to obtain, defaults to 14
+    :type filters.zoom: int
+
     :param filters.min_captured_at: The minimum date to filter till
     :type filters.min_captured_at: str
 
@@ -211,24 +206,37 @@ def get_image_looking_at_controller(
     :rtype: dict
     """
 
+    # Converting 'at' of type Coordinates|List to dict
+    at: dict = coord_or_list_to_dict(data=at)
+
     # Checking if a non valid key
     # has been passed to  the function
     # If that is the case, throw an exception
     image_check(kwargs=filters)
 
-    looker = get_image_close_to_controller(
-        longitude=looker["lng"], latitude=looker["lat"], kwargs=filters
-    ).to_dict()
+    at_image_data = GeneralAdapter().fetch_image_tiles(
+        zoom=filters["zoom"] if "zoom" in filters else 14,
+        longitude=at["lng"],
+        latitude=at["lat"],
+        layer="image",
+    )
 
-    if not looker["features"]:
-        return GeoJSON(geojson=looker)
+    if not at_image_data["features"]:
+        return GeoJSON(geojson=at_image_data)
+
+    # Filters are to be applied to the data retrieved from the database in the following logic
+    # # 1. Filter by the filters provided by the filters parameter
+    # # 2. Secondly, from the fetched tile, trim out data that falls outside the given radius, if
+    # no radius is specified, assume 20m to be safe
+    # # 2. Then, from the remaining feature points, extract only those that are qualified by the
+    # "hits_by_look_at" function
 
     # Filter the unfiltered results by the given filters
     return GeoJSON(
         geojson=json.loads(
             merged_features_list_to_geojson(
                 pipeline(
-                    data=looker,
+                    data=at_image_data,
                     components=[
                         # Filter by `max_captured_at`
                         {
@@ -255,6 +263,14 @@ def get_image_looking_at_controller(
                         }
                         if "organization_id" in filters
                         else {},
+                        # Filter using kwargs.radius
+                        {
+                            "filter": "haversine_dist",
+                            "radius": filters.get("radius"),
+                            "coords": [at["lng"], at["lat"]],
+                        }
+                        if "radius" in filters
+                        else {},
                         # Filter by `hits_by_look_at`
                         {"filter": "hits_by_look_at", "at": at},
                     ],
@@ -264,6 +280,55 @@ def get_image_looking_at_controller(
     )
 
 
+def is_image_being_looked_at_controller(
+    at: Union[dict, Coordinates, list],
+    filters: dict,
+) -> bool:
+    """
+    Checks if the image with coordinates 'at' is looked with the given filters.
+
+    :param at: The dict of coordinates of the position of the looking at coordinates.
+
+        Format::
+
+            >>> at_dict = {
+            ...     'lng': 'longitude',
+            ...     'lat': 'latitude'
+            ... }
+            >>> at_list = [12.954940544167, 48.0537894275]
+            >>> from mapillary.models.geojson import Coordinates
+            >>> at_coord: Coordinates = Coordinates(lng=12.954940544167, lat=48.0537894275)
+
+    :type at: Union[dict, mapillary.models.geojson.Coordinates, list]
+
+    :param filters.zoom: The zoom level of the tiles to obtain, defaults to 14
+    :type filter.zoom: int
+
+    :param filters.min_captured_at: The minimum date to filter till
+    :type filters.min_captured_at: str
+
+    :param filters.max_captured_at: The maximum date to filter upto
+    :type filters.max_captured_at: str
+
+    :param filters.radius: The radius that the geometry points will lie in
+    :type filters.radius: float
+
+    :param filters.image_type: Either 'pano', 'flat' or 'all'
+    :type filters.image_type: str
+
+    :param filters.organization_id: The organization to retrieve the data for
+    :type filters.organization_id: str
+
+    :return: True if the image is looked at by the given looker and at coordinates, False otherwise
+    :rtype: bool
+    """
+
+    result: dict = get_image_looking_at_controller(at=at, filters=filters).to_dict()
+
+    # If the result is empty, the image is not looked at, hence return False
+    return len(result["features"]) != 0
+
+
 def get_image_thumbnail_controller(image_id: str, resolution: int) -> str:
     """
     This controller holds the business logic for retrieving
