@@ -5,14 +5,14 @@
 mapillary.models.api.vector_tiles
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-This module contains the adapter design for the Vector Tiles API of Mapillary APIv4, Vector tiles
+This module contains the adapter design for the Vector Tiles API of Mapillary API v4, Vector tiles
 provide an easy way to visualize vast amounts of data. Vector tiles support filtering and querying
 rendered features. Mapillary vector tiles follow the Mapbox tile specification.
 
 For more information, please check out https://www.mapillary.com/developer/api-documentation/.
 
-:copyright: (c) 2021 Facebook
-:license: MIT LICENSE
+- Copyright: (c) 2021 Facebook
+- License: MIT LICENSE
 """
 
 # Package imports
@@ -20,24 +20,24 @@ from vt2geojson.tools import vt_bytes_to_geojson
 import mercantile
 
 # Local imports
-
-# # Exception handling
-from mapillary.models.exceptions import InvalidOptionError
+# # Config
+from mapillary.config.api.vector_tiles import VectorTiles
 
 # # Client import
 from mapillary.models.client import Client
 
-# # Config
-from mapillary.config.api.vector_tiles import VectorTiles
+# # Exception handling
+from mapillary.models.exceptions import InvalidOptionError
 
 # # Models
 from mapillary.models.geojson import GeoJSON
 
 
 class VectorTilesAdapter(object):
-    """Adapter model for dealing with the VectorTiles API, through the DRY principle. The
+    """
+    Adapter model for dealing with the VectorTiles API, through the DRY principle. The
     VectorTilesAdapter class can be instantiated in the controller modules, providing an
-    abstraction layer that uses the Client class, endpoints provided by the APIv4 under
+    abstraction layer that uses the Client class, endpoints provided by the API v4 under
     `/config/api/vector_tiles.py`.
 
     It performs parsing, handling of layers, properties, and fields to make it easier to
@@ -47,15 +47,19 @@ class VectorTilesAdapter(object):
     inputs/outputs
 
     Usage::
+
+        >>> import mapillary
+        >>> from mapillary.models.api.vector_tiles import VectorTilesAdapter
+        >>> latitude, longitude = 30, 31
         >>> VectorTilesAdapter().fetch_layer(layer="image", zoom=14, longitude=longitude,
-                latitude=latitude,
-            )
+        ...     latitude=latitude,
+        ... )
         >>> VectorTilesAdapter().fetch_layer(layer="sequence", zoom=10, longitude=longitude,
-                latitude=latitude,
-            )
+        ...     latitude=latitude,
+        ... )
         >>> VectorTilesAdapter().fetch_layer(layer="overview", zoom=3, longitude=longitude,
-                latitude=latitude,
-            )
+        ...     latitude=latitude,
+        ... )
     """
 
     # FOR DEVELOPERS
@@ -85,7 +89,8 @@ class VectorTilesAdapter(object):
     def fetch_layer(
         self, layer: str, longitude: float, latitude: float, zoom: int = 14
     ) -> dict:
-        """Fetches an image tile layer depending on the coordinates, and the layer selected
+        """
+        Fetches an image tile layer depending on the coordinates, and the layer selected
         along with the zoom level
 
         :param layer: Either 'overview', 'sequence', 'image'
@@ -105,7 +110,7 @@ class VectorTilesAdapter(object):
         """
 
         # Checking if the correct parameters are passed
-        self.__check_parameters(longitude=longitude, latitude=latitude)
+        VectorTilesAdapter.__check_parameters(longitude=longitude, latitude=latitude)
 
         # Check for the correct zoom values against the layer specified
         self.__zoom_range_check(layer=layer, zoom=zoom)
@@ -123,7 +128,8 @@ class VectorTilesAdapter(object):
     def fetch_computed_layer(
         self, layer: str, zoom: int, longitude: float, latitude: float
     ):
-        """Same as `fetch_layer`, but gets in return computed tiles only.
+        """
+        Same as `fetch_layer`, but gets in return computed tiles only.
         Depends on the layer, zoom level, longitude and the latitude specifications
 
         :param layer: Either 'overview', 'sequence', 'image'
@@ -143,7 +149,7 @@ class VectorTilesAdapter(object):
         """
 
         # Checking if the correct parameters are passed
-        self.__check_parameters(longitude=longitude, latitude=latitude)
+        VectorTilesAdapter.__check_parameters(longitude=longitude, latitude=latitude)
 
         # Check for the correct zoom values against the layer specified
         self.__zoom_range_check(layer=layer, zoom=zoom)
@@ -161,7 +167,8 @@ class VectorTilesAdapter(object):
     def fetch_features(
         self, feature_type: str, zoom: int, longitude: float, latitude: float
     ):
-        """Fetches specified features from the coordinates with the apppropriate zoom level
+        """
+        Fetches specified features from the coordinates with the appropriate zoom level
 
         :param feature_type: Either `point`, or `tiles`
         :type feature_type: str
@@ -180,7 +187,7 @@ class VectorTilesAdapter(object):
         """
 
         # Checking if the correct parameters are passed
-        self.__check_parameters(longitude=longitude, latitude=latitude)
+        VectorTilesAdapter.__check_parameters(longitude=longitude, latitude=latitude)
 
         # Check for the correct zoom values against the layer specified
         self.__zoom_range_check(layer="map", zoom=zoom)
@@ -202,13 +209,14 @@ class VectorTilesAdapter(object):
         zoom: int = 14,
         is_computed: bool = False,
     ) -> GeoJSON:
-        """Fetches multiple vector tiles based on a list of multiple coordinates in a listed format
+        """
+        Fetches multiple vector tiles based on a list of multiple coordinates in a listed format
 
         :param coordinates: A list of lists of coordinates to get the vector tiles for
         :type coordinates: "list[list]"
 
         :param layer: Either "overview", "sequence", "image", "traffic_sign", or "map_feature",
-        defaults to "image"
+            defaults to "image"
         :type layer: str
 
         :param zoom: the zoom level [0, 14], inclusive. Defaults to 14
@@ -217,16 +225,13 @@ class VectorTilesAdapter(object):
         :param is_computed: Will to be fetched layers be computed? Defaults to False
         :type is_computed: bool
 
-        :return: A geojson with merged featurs from all unique vector tiles
+        :return: A geojson with merged features from all unique vector tiles
         :rtype: dict
         """
 
         # Check for the correct zoom values against the layer specified
         self.__zoom_range_check(layer=layer, zoom=zoom)
 
-        # Let `tiles` be a unique tile set
-        tiles = set()
-
         # The output resultant geojson
         geojson: GeoJSON = GeoJSON(
             geojson={"type": "FeatureCollection", "features": []}
@@ -250,8 +255,6 @@ class VectorTilesAdapter(object):
 
         for tile in tiles:
 
-            result = []
-
             if is_computed:
                 result = (
                     self.__preprocess_computed_layer(
@@ -285,27 +288,25 @@ class VectorTilesAdapter(object):
         feature_type: str,
         zoom: int = 14,
     ) -> GeoJSON:
-        """Fetches map features based on a list Polygon object
+        """
+        Fetches map features based on a list Polygon object
 
         :param coordinates: A list of lists of coordinates to get the map features for
         :type coordinates: "list[list]"
 
-        :param layer: Either "point", "traffic_signs", defaults to "point"
-        :type layer: str
+        :param feature_type: Either "point", "traffic_signs", defaults to "point"
+        :type feature_type: str
 
         :param zoom: the zoom level [0, 14], inclusive. Defaults to 14
         :type zoom: int
 
-        :return: A geojson with merged featurs from all unique vector tiles
+        :return: A geojson with merged features from all unique vector tiles
         :rtype: dict
         """
 
         # Check for the correct zoom values against the layer specified
         self.__zoom_range_check(layer="map_feature", zoom=zoom)
 
-        # Let `tiles` be a unique tile set
-        tiles = set()
-
         # The output resultant geojson
         geojson: GeoJSON = GeoJSON(
             geojson={"type": "FeatureCollection", "features": []}
@@ -328,7 +329,6 @@ class VectorTilesAdapter(object):
         )
 
         for tile in tiles:
-
             geojson.append_features(
                 self.__preprocess_features(
                     # The layer to retrieve from
@@ -342,18 +342,13 @@ class VectorTilesAdapter(object):
 
         return geojson
 
+    @staticmethod
     def __check_parameters(
-        self,
         longitude: float,
         latitude: float,
     ):
-        """Range checking for the paramters of longitude, latitude, layer, zoom
-
-        :param layer: Either 'overview', 'sequence', 'image'
-        :type layer: str
-
-        :param zoom: The zoom level, [0, 14], inclusive
-        :type zoom: int
+        """
+        Range checking for the parameters of longitude, latitude, layer, zoom
 
         :param longitude: The longitude of the coordinates
         :type longitude: float
@@ -369,7 +364,6 @@ class VectorTilesAdapter(object):
 
         # If lng not in the range [-180, 180], inclusive
         if longitude <= -180 or longitude >= 180:
-
             # Raise exception
             raise InvalidOptionError(
                 param="longitude", value=longitude, options=[-180, 180]
@@ -377,7 +371,6 @@ class VectorTilesAdapter(object):
 
         # If lat not in the range [-90, 90], inclusive
         if latitude <= -90 or latitude >= 90:
-
             # Raise exception
             raise InvalidOptionError(
                 param="latitude", value=latitude, options=[-180, 180]
@@ -385,17 +378,16 @@ class VectorTilesAdapter(object):
 
     def __zoom_range_check(self, layer: str, zoom: int):
 
-        """Checks for the correct zoom values for te specified layer
+        """
+        Checks for the correct zoom values for te specified layer
 
         :param layer: Either 'overview', 'sequence', 'image', or 'map'
         :type layer: str
 
-        :param zoom: The zoom levls,
+        :param zoom: The zoom levels,
         :type zoom: int
 
-        ...
         :raises InvalidOptionError: Invalid option passed
-        ...
 
         :return: A GeoJSON for the return object
         :rtype: dict
@@ -403,7 +395,6 @@ class VectorTilesAdapter(object):
 
         # If zoom is not in the valid range of values
         if zoom < self.__min_zoom or zoom > self.__max_zoom:
-
             # Raise an exception for the invalid values passed
             raise InvalidOptionError(
                 # Parameters accordingly
@@ -417,7 +408,6 @@ class VectorTilesAdapter(object):
 
             # If zoom is not in the given range of values
             if zoom not in [_ for _ in range(self.__min_zoom, 5 + 1)]:
-
                 # Raise an exception for the invalid zoom value
                 raise InvalidOptionError(
                     # Parameters accordingly
@@ -431,7 +421,6 @@ class VectorTilesAdapter(object):
 
             # IF zoom not in the given range of values
             if zoom not in [_ for _ in range(6, 14 + 1)]:
-
                 # Raise an exception for the invalid zoom value
                 raise InvalidOptionError(
                     # Parameters accordingly
@@ -445,7 +434,6 @@ class VectorTilesAdapter(object):
 
             # If zoom was not 14
             if zoom != 14:
-
                 # Raise an exception for the invalid zoom value
                 raise InvalidOptionError(param="zoom", value=zoom, options=[14])
 
@@ -461,16 +449,14 @@ class VectorTilesAdapter(object):
             )
 
     def __preprocess_layer(self, layer: str, tile: mercantile.Tile, zoom: int):
-        """Preprocessing uncomputed layers
+        """
+        Preprocessing un-computed layers
 
         :param layer: Either 'overview', 'sequence', 'image'
         :type layer: str
 
-        :param longitude: The longitude of the layer
-        :type longitude: float
-
-        :param latitude: The latitude of the layer
-        :type latitude: float
+        :param tile: The specified tile
+        :type tile: mercantile.Tile
 
         :param zoom: The zoom level
         :type zoom: int
@@ -482,6 +468,7 @@ class VectorTilesAdapter(object):
         # * See "FOR DEVELOPERS (3, 3.1)"
 
         # Extract the url depending upon the layer
+        url = ""
 
         # For overview
         if layer == "overview":
@@ -499,7 +486,7 @@ class VectorTilesAdapter(object):
 
         # Convert bytes to GeoJSON
         return vt_bytes_to_geojson(
-            # Paramters, appropriately
+            # Parameters, appropriately
             b_content=self.client.get(url).content,
             x=tile.x,
             y=tile.y,
@@ -508,16 +495,14 @@ class VectorTilesAdapter(object):
         )
 
     def __preprocess_computed_layer(self, layer: str, tile: mercantile.Tile, zoom: int):
-        """Preprocessing computed layers
+        """
+        Preprocessing computed layers
 
         :param layer: Either 'overview', 'sequence', 'image'
         :type layer: str
 
-        :param longitude: The longitude of the layer
-        :type longitude: float
-
-        :param latitude: The latitude of the layer
-        :type latitude: float
+        :param tile: The specified tile
+        :type tile: mercantile.Tile
 
         :param zoom: The zoom level
         :type zoom: int
@@ -528,7 +513,8 @@ class VectorTilesAdapter(object):
 
         # * See "FOR DEVELOPERS (3, 3.1)"
 
-        # Extracing url from specified VectorTiles endpoint
+        # Extracting url from specified VectorTiles endpoint
+        url = ""
 
         # For overview
         if layer == "overview":
@@ -557,16 +543,14 @@ class VectorTilesAdapter(object):
     def __preprocess_features(
         self, feature_type: str, tile: mercantile.Tile, zoom: int
     ) -> dict:
-        """Preprocess features
+        """
+        Preprocess features
 
         :param feature_type: Either 'point', 'traffic_signs'
         :type feature_type: str
 
-        :param longitude: The longitude of the feature
-        :type longitude: float
-
-        :param latitude: The latitude of the feature
-        :type latitude: float
+        :param tile: The specified tile
+        :type tile: mercantile.Tile
 
         :param zoom: The zoom level
         :type zoom: int
@@ -577,7 +561,7 @@ class VectorTilesAdapter(object):
 
         # * See "FOR DEVELOPERS (3, 3.1)"
 
-        # Extracing url from specified VectorTiles endpoint
+        # Extracting url from specified VectorTiles endpoint
 
         # For 'point'
         if feature_type == "point":
@@ -586,7 +570,7 @@ class VectorTilesAdapter(object):
 
         # For 'traffic_signs'
         elif feature_type == "traffic_signs":
-            url = VectorTiles.get_map_feature_tiles(x=tile[0], y=tile[1], z=zoom)
+            url = VectorTiles.get_map_feature_traffic_sign(x=tile[0], y=tile[1], z=zoom)
 
         # If both are not present
         else:
